@@ -9,9 +9,9 @@ import $ from "jquery";
 document.addEventListener("DOMContentLoaded", function () {
     document.getElementById("nav-icon").addEventListener("click", function () {
         $(this).toggleClass('open');
-
         $('#sidebar').sidebar('setting', 'onHide', function (){
           $('#nav-icon').removeClass('open');
-        }).sidebar('toggle');
+        })
+        $('#sidebar').sidebar('show');
     });
 });
