@@ -10,6 +10,7 @@
 import requests
 from flask import Blueprint, render_template
 from invenio_cache import current_cache
+from invenio_rdm_records.resources.serializers import UIJSONSerializer
 
 from .search import FrontpageRecordsSearch
 
@@ -78,7 +79,14 @@ def create_blueprint(app):
     @blueprint.route("/")
     def tuw_index():
         records = FrontpageRecordsSearch()[:5].sort("-created").execute()
-        return render_template("invenio_theme_tuw/frontpage.html", records=records_serializer(records))
+        return render_template("invenio_theme_tuw/frontpage.html", records=_records_serializer(records))
+
+    def _records_serializer(records=None):
+        """Serialize list of records."""
+        record_list = []
+        for record in records:
+            record_list.append(UIJSONSerializer().serialize_object_to_dict(record.to_dict()))
+        return record_list
 
     @blueprint.route("/tuw/policies")
     def tuw_policies():
